@@ -7,6 +7,7 @@
 
 from ctypes import cdll, create_string_buffer, c_int, byref, c_bool, c_double
 import click
+import platform
 
 # ============================================================================
 # INTERNAL IMPORTS
@@ -25,9 +26,27 @@ class Configurator:
         Example:
             To use the ``Simulator`` declare in a string the ``path`` to the simulator ::
 
-                >>> path = "path/to/simluator.so"
+                >>> path = "path/to/libSymuyVia.dylib"
                 >>> simulator = Configurator(libraryPath = path) 
 
+        Args:
+            libraryPath (str): 
+                Absolute path towards the simulator library
+
+            bufferSize (int): 
+                Size of the buffer for message for data received from simulator
+
+            writeXML (bool): 
+                Flag to turn on writting the XML output
+
+            traceFlow (bool):
+                Flag to determine tracing or not the flow / trajectories
+
+            totalSteps (int):
+                Define the number of iterations of a simulation 
+
+            stepLaunchMode (str):
+                Determine to way to launch the ``RunStepEx``. Options ``lite``/``full``
 
         :return: Configurator object with simulation parameters
         :rtype: Configurator
@@ -36,28 +55,33 @@ class Configurator:
     def __init__(
         self,
         bufferSize: int = CT.BUFFER_STRING,
-        writeXML: bool = True,
-        traceFlow: bool = False,
-        libraryPath: str = "",
-        totalSteps: int = 0,
-        stepLaunchMode: str = "lite",
+        writeXML: bool = CT.WRITE_XML,
+        traceFlow: bool = CT.TRACE_FLOW,
+        libraryPath: str = CT.DCT_DEFAULT_PATHS[("symuvia", platform.system())],
+        totalSteps: int = CT.TOTAL_SIMULATION_STEPS,
+        stepLaunchMode: str = CT.LAUNCH_MODE,
     ) -> None:
         """ Configurator class for containing specific simulator parameter
-        
-            :param bufferSize: Provide an integer for buffer, defaults to CT.BUFFER_STRING
-            :type bufferSize: int, optional
-            :param writeXML: Flag to write XML file, defaults to True
-            :type writeXML: bool, optional
-            :param traceFlow: Flag to trace Flow / Traces, defaults to False
-            :type traceFlow: bool, optional
-            :param libraryPath: Stores the path of a traffic simulator, defaults to ""
-            :type libraryPath: str, optional
-            :param totalSteps: total number of simulation steps, defaults to 0
-            :type totalSteps: int, optional
-            :param stepLaunchMode: lite / full, defaults to "lite"
-            :type stepLaunchMode: str, optional
-            :return: Configurator object with simulation parameters
-            :rtype: Configurator
+
+            Args:
+
+            bufferSize (int): 
+                Size of the buffer for message for data received from simulator
+
+            writeXML (bool): 
+                Flag to turn on writting the XML output
+
+            traceFlow (bool):
+                Flag to determine tracing or not the flow / trajectories
+
+            libraryPath (str): 
+                Absolute path towards the simulator library
+
+            totalSteps (int):
+                Define the number of iterations of a simulation 
+
+            stepLaunchMode (str):
+                Determine to way to launch the ``RunStepEx``. Options ``lite``/``full``
         """
         click.echo("Configurator: Initialization")
         self.bufferString = create_string_buffer(bufferSize)
