@@ -13,6 +13,8 @@
      **Variable**                 **Description**
     ----------------------------  ---------------------------------
     ``BUFFER_STRING``              Buffer size
+    ``DEFAULT_LIB_OSX``            Default OS X library path 
+    ``DEFAULT_LIB_LINUX``          Default Linux library path      
     ``FIELD_DATA``                 Vehicle trajectory data
     ``FIELD_FORMAT``               Trajectory data types
     ``HOUR_FORMAT``                Time format
@@ -28,26 +30,58 @@
 
 """
 
+# ============================================================================
+# STANDARD  IMPORTS
+# ============================================================================
+
 from datetime import date, datetime, timedelta
+import os
 from numpy import array, float64, int32
 
+# ============================================================================
+# CLASS AND DEFINITIONS
+# ============================================================================
+
+# Default simulator per platform
+
 # *****************************************************************************
-# CONNECTOR
+# DEFAULT PATHS TO FIND SIMULATOR PLATFORMS
 # *****************************************************************************
-# Buffer string size
+
+DEFAULT_LIB_OSX = "/Users/andresladino/Documents/01-Code/04-Platforms/dev-symuvia/build/lib/libSymuVia.dylib"
+
+DEFAULT_LIB_LINUX = "/home/build-symuvia/build/symuvia/libSymuVia.so"
+
+DEFAULT_LIB_WINDOWS = "/home/build-symuvia/build/symuvia/libSymuVia.dll"
+
+# *****************************************************************************
+# DEFAULT SIMULATOR/ OS ASSOCIATION
+# *****************************************************************************
+
+
+DCT_SIMULATORS = {"Darwin": "symuvia", "Linux": "symuvia", "Windows": "symuvia"}
+
+# Feasible Simulator/Platform Paths/Libs
+
+DCT_DEFAULT_PATHS = {
+    ("symuvia", "Darwin"): os.environ.get("SYMUVIALIB", DEFAULT_LIB_OSX),
+    ("symuvia", "Linux"): os.environ.get("SYMUVIALIB", DEFAULT_LIB_LINUX),
+    ("symuvia", "Windows"): os.environ.get("SYMUVIALIB", DEFAULT_LIB_WINDOWS),
+}
+
+# *****************************************************************************
+# DATA SYMUVIA
+# *****************************************************************************
+
+# *****************************************************************************
+# STREAM CONSTANTS
+# *****************************************************************************
+
 BUFFER_STRING = 1000000
-
-
-# *****************************************************************************
-# DATA SYMUVIA
-# *****************************************************************************
-HOUR_FORMAT = "%H:%M:%S"  # Format time from xml file
-
-
-# *****************************************************************************
-# DATA SYMUVIA
-# *****************************************************************************
-RADIOUS_ANT = 500  # meters. Default distance scope antenna before
+WRITE_XML = False
+TRACE_FLOW = False
+LAUNCH_MODE = "lite"
+TOTAL_SIMULATION_STEPS = 0
 
 FIELD_DATA = {
     "@abs": "abscisa",
@@ -91,12 +125,12 @@ FIELD_FORMATAGG = {
     "elevation": (array, FLOAT_SELECT),
 }
 
-
 # *****************************************************************************
 # XML Data
 # *****************************************************************************
 
 # DATE/TIME INFORMATION
+HOUR_FORMAT = "%H:%M:%S"
 DELTA_TIME = timedelta(minutes=1)
 TIME_STEP = timedelta(seconds=1).total_seconds()
 today = date.today().strftime("%Y-%m-%d")
@@ -108,7 +142,7 @@ ed_time_str = ed_time.strftime("%H:%M:%S")
 # SIMULATION INFORMATION
 DCT_SIMULATION_INFO = {
     "id": "simID",
-    "pasdetemps": f"TIME_STEP",
+    "pasdetemps": f"{TIME_STEP}",
     "debut": f"st_time_str",
     "fin": f"ed_time_str",
     "loipoursuite": "exacte",
@@ -130,12 +164,7 @@ DCT_EXPORT_INFO = {
 }
 
 # TAFFIC INFORMATION
-DCT_TRAFIC_INFO = {
-    "id": "trafID",
-    "accbornee": "true",
-    "coeffrelax": "4",
-    "chgtvoie_ghost": "false",
-}
+DCT_TRAFIC_INFO = {"id": "trafID", "accbornee": "true", "coeffrelax": "4", "chgtvoie_ghost": "false"}
 
 # NETWORK INFORMATION
 DCT_NETWORK_INFO = {"id": "resID"}
@@ -151,23 +180,27 @@ DCT_SCENARIO_INFO = {
 }
 
 
-TP_VEHTYPES = (
-    {"id": "HDV", "w": "-5", "kx": "0.12", "vx": "25"},
-    {"id": "CAV", "w": "-5", "kx": "0.12", "vx": "25"},
-)
+TP_VEHTYPES = ({"id": "HDV", "w": "-5", "kx": "0.12", "vx": "25"}, {"id": "CAV", "w": "-5", "kx": "0.12", "vx": "25"})
 
-TP_ACCEL = (
-    {"ax": "1.5", "vit_sup": "5.8"},
-    {"ax": "1", "vit_sup": "8"},
-    {"ax": "0.5", "vit_sup": "infini"},
-)
+TP_ACCEL = ({"ax": "1.5", "vit_sup": "5.8"}, {"ax": "1", "vit_sup": "8"}, {"ax": "0.5", "vit_sup": "infini"})
 
 # *****************************************************************************
-# DATA CONTROL
+# CONTROL
 # *****************************************************************************
+
 BUFFER_CONTROL = 10  # Amount of control samples stored in memory
 
 # *****************************************************************************
-# DATA VEHICLE DYNAMICS
+# VEHICLE DYNAMICS
 # *****************************************************************************
+
 ENGINE_CONSTANT = 0.2
+
+# *****************************************************************************
+# COMMUNICATION
+# *****************************************************************************
+
+RADIOUS_ANT = 500
+
+if __name__ == "__main__":
+    print(os.environ.get("SYMUVIALIB"))
